@@ -1,8 +1,3 @@
-try:
-    from configparser import ConfigParser
-except ImportError:
-    from ConfigParser import ConfigParser  # noqa
-
 try:
     from unittest import mock
 except ImportError:
